==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-statusnotifier/translations/statusnotifier_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="28"/>
        <location filename="../statusnotifierconfiguration.ui" line="38"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="31"/>
        <source>Attention period:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="41"/>
        <source> minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="72"/>
        <source>Change visibility of items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="85"/>
        <source>Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="90"/>
        <source>Visibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Auto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always hide</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.4.0.orig.tar.xz: lxqt-panel-1.4.0/plugin-statusnotifier/translations/statusnotifier_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Nastavenia widgetu Status Notifier</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="28"/>
        <location filename="../statusnotifierconfiguration.ui" line="38"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Ak automaticky skrývaná položka potrebuje pozornosť, ostane viditeľná po zadaný čas.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="31"/>
        <source>Attention period:</source>
        <translation>Čas upozornenia:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="41"/>
        <source> minute(s)</source>
        <translation> minút</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="72"/>
        <source>Change visibility of items</source>
        <translation>Viditeľnosť položiek</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="85"/>
        <source>Item</source>
        <translation>Položka</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="90"/>
        <source>Visibility</source>
        <translation>Viditeľnosť</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always show</source>
        <translation>Zobraziť vždy</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Auto-hide</source>
        <translation>Automaticky skryť</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always hide</source>
        <translation>Vždy skryť</translation>
    </message>
</context>
</TS>
